Types and functions for posts.
Structs
- Represents a post creator as returned in a posts API response.
- List of Creators for displaying in the TUI.
- Represents a post as returned in a posts API response.
- Represents a response from the Post endpoint.
- Represents a table of responses to the Post endpoint.
- Represents a list of responses to the Post endpoint.
- List of Posts for displaying in the TUI.